############################################################################
#
#  Licensed Materials - Property of IBM
#  5698-TEC
#
#  (C) Copyright IBM Corp. 2002, 2004.  All Rights Reserved.
#
#  US Government Users Restricted Rights - Use, duplication or
#  disclosure restricted by GSA ADP Schedule Contract with
#  IBM Corp.
#
#   File Information: images/tdw_weps/ec2/v110/etl/generic/EC2_c05_s030_long_comparison.pl, tec_data_warehouse, tec_3.9.0
#   Revision: 1.1
#   Date: 9/9/04 10:07:07
############################################################################
#!/usr/bin/perl

use Time::Local;

$numberOfCommas=8;

if (! @ARGV) {
    $log = 'ec2_c05_s030_long_comparison.log';
    if (! open(LOG, ">$log")) {
        print "Long Comparison Error: Unable to open the specified log file for writing:\n";
        print "\n    \"$log\".\n\n";
        print "$!\n";
        exit(1);
    }
    print LOG "\nLong Comparison Error: a file name is required.\n\n";
    usage(1);
}

$log = $ARGV[0].'.log';
if (! open(LOG, ">$log")) {
    print "\nLong Comparison Error: Unable to open the specified log file for writing:\n";
    print "\n    \"$log\".\n\n";
    print "$!\n";
    exit(1);
    }
print LOG "Logfile $log opened.\n";

$hfile = $ARGV[0].'.preedit';
if (! open(HOSTS, "<$hfile")) {
    print LOG "\nLong Comparison Error: unable to open the specified hostname file for reading:\n";
    print LOG "\n    \"$hfile\".\n\n";
    print LOG "$!\n";
    close(LOG);
    exit(1);
}

 $out = $ARGV[0].'.postedit';
 if (! open(OUT, ">$out")) {
        print LOG "\nLong Comparison Error: Unable to open the specified output file for writing:\n";
        print LOG "\n    \"$out\".\n\n";
        print LOG "$!\n";
        close(LOG);
        exit(1);
    }

binmode HOSTS;

while ($inlineTmp = <HOSTS>) {

    $inline="";
    $cnt=$inlineTmp =~ tr/,/,/;

    $inlineTmp =~ s/\032/<SUB>/g;

    while ($cnt < $numberOfCommas){
	$inlineTmp =~ s/\r\n$/<LF>/;
	$inlineTmp =~ s/\n$/<LF>/;
	$inlineTmp =~ s/\032/<SUB>/g;

        $inline .= $inlineTmp;
        if (!eof){
           $inlineTmp = <HOSTS>;
	}
        else{
           last;
	}
        $cnt += ($inlineTmp =~ tr/,/,/);
    }

    $inline .= $inlineTmp;

    @inlist = split_commas($inline);
    print LOG ">>Processing Input: \"$inlist[0]\",\"$inlist[1]\",\"$inlist[2]\",\"$inlist[3]\",\"$inlist[4]\",\"$inlist[5]\",\"$inlist[6]\",\"$inlist[7]\",\"$inlist[8]\"\n";
    @outline = ();
    
    $inlist[0] =~ s/\s+$//;
    $inlist[1] =~ s/\s+$//;
    
    if ( $inlist[0] ne $inlist[1] ) {

	$outline[0] = $inlist[3];
	$outline[0] =~ s/\s+$//;

	$outline[1] = $inlist[1];
	$outline[1] =~ s/\s+$//;

	$outline[2] = $inlist[7];
	$outline[2] =~ s/\s+$//;
	
	$outline[3] = $inlist[8];
	$outline[3] =~ s/\s+$//;

	print OUT "\"$outline[0]\",\"$outline[1]\",\"$outline[2]\",\"$outline[3]\"\n";
    }
}    

print LOG "\nEnd of Input.\n";
print LOG "End of Processing.\n";

close(HOSTS);
close(OUT);
close(LOG);

exit(0);

sub usage {
    $rc = @_;
    print LOG <<USAGE;
ec2_c05_s030_long_comparison.pl <HOSTS_FILE>\n
	where HOSTS_FILE.preedit is a csv file
USAGE
    close(LOG);
    exit($rc);
}

sub split_commas {
    my $line = shift;
    my @listitems = ();
    push(@listitems, $+) while $line =~ m{
    "([^\"\\]*(?:\\.[^\"\\]*)*)",?
      |  ([^,]+),?
      | ,
    }gx;
    push(@listitems, undef) if substr($line, -1,1) eq ',';
    return @listitems;
}
